## Beta features (under development)

Here are a few on-going projects to extend the Collective Knowledge Playground 
being developed by [cKnowledge.org](https://cKnowledge.org) and [cTuning.org](https://cTuning.org)
using [Collective Mind automation recipes (CM scripts)]({{URL_PREFIX}}?action=scripts):

* [MLPerf results explorer](https://access.cknowledge.org/mlperf-explorer) 
* [LLM-based assistant to run MLPerf benchmarks](https://access.cknowledge.org/assistant) 

Feel free to suggest your projects and extensions using [GitHub issues](https://github.com/mlcommons/ck/issues)!
